@@ -132,7 +132,10 @@ def version(*, retry=False, noop=False, force_level=None, **kwargs):
 
     # Bump the version
     set_new_version(new_version)
-    if config.get("commit_version_number", config.get("version_source") == "commit",):
+    if config.get(
+        "commit_version_number",
+        config.get("version_source") == "commit",
+    ):
         commit_new_version(new_version)
     tag_new_version(new_version)
 
@@ -161,7 +164,8 @@ def changelog(*, unreleased=False, noop=False, post=False, **kwargs):
         log = generate_changelog(current_version, None)
     else:
         log = generate_changelog(previous_version, current_version)
-    logger.info(markdown_changelog(current_version, log, header=False))
+    # print is used to keep the changelog on stdout, separate from log messages
+    print(markdown_changelog(current_version, log, header=False))
 
     # Post changelog to HVCS if enabled
     if not noop and post:
